tiled.structures.xarray.DataArrayStructure
==========================================

.. currentmodule:: tiled.structures.xarray

.. autoclass:: DataArrayStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataArrayStructure.__init__
      ~DataArrayStructure.from_json
   
   

   
   
   